bayespy.inference.vmp.nodes.poisson.PoissonDistribution.plates_from_parent
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.plates_from_parent